@@ -6,7 +6,7 @@
 
 
 import os
-from .attribute_dict import AttributeDict
+from .attribute_dict import SimpleAttributeDict, AttributeDict
 from .counter import Counter
 
 
@@ -16,21 +16,23 @@ SECTION_SPLITTER = "-" * 50
 
 
 # runtime context
-class RuntimeContext(AttributeDict):
+class RuntimeContext(SimpleAttributeDict):
     """stores runtime context, includes application instance, callbacks,
     test suite name, minimo root path, and etc.
     """
 
-    def __init__(self):
+    def __init__(self, defaults={}):
         super(RuntimeContext, self).__init__({
             "app": None,
             "counter": None,
             "reporter": None,
             "callbacks": None,
             "suite_name": None,
-            "output_path": None
+            "output_path": None,
+            "config": AttributeDict(),
         })
 
+
 ctx = RuntimeContext()
 ctx.counter = Counter()
 ctx.minimo_root_path = os.path.dirname(__file__)
